% Auto-generated chapter 25 for abudawud
% Hadiths in this chapter: 70

\hadithdefcmd{abudawud}{3571}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا عَمْرُو بْنُ أَبِي عَمْرٍو، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ وَلِيَ الْقَضَاءَ فَقَدْ ذُبِحَ بِغَيْرِ سِكِّينٍ ‏"‏ ‏.‏\hadithno{3571}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Hurayrah: The Prophet (ﷺ) said: He who has been appointed a judge has been killed without a knife}}
\hadithdefcmd{abudawud}{3572}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا بِشْرُ بْنُ عُمَرَ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، عَنْ عُثْمَانَ بْنِ مُحَمَّدٍ الأَخْنَسِيِّ، عَنِ الْمَقْبُرِيِّ، وَالأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ جُعِلَ قَاضِيًا بَيْنَ النَّاسِ فَقَدْ ذُبِحَ بِغَيْرِ سِكِّينٍ ‏"‏ ‏.‏\hadithno{3572}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurayrah: The Prophet (ﷺ) said: He who has been appointed a judge among the people has been killed without a knife}}
\hadithdefcmd{abudawud}{3573}{حَدَّثَنَا مُحَمَّدُ بْنُ حَسَّانَ السَّمْتِيُّ، حَدَّثَنَا خَلَفُ بْنُ خَلِيفَةَ، عَنْ أَبِي هَاشِمٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الْقُضَاةُ ثَلاَثَةٌ وَاحِدٌ فِي الْجَنَّةِ وَاثْنَانِ فِي النَّارِ فَأَمَّا الَّذِي فِي الْجَنَّةِ فَرَجُلٌ عَرَفَ الْحَقَّ فَقَضَى بِهِ وَرَجُلٌ عَرَفَ الْحَقَّ فَجَارَ فِي الْحُكْمِ فَهُوَ فِي النَّارِ وَرَجُلٌ قَضَى لِلنَّاسِ عَلَى جَهْلٍ فَهُوَ فِي النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا أَصَحُّ شَىْءٍ فِيهِ يَعْنِي حَدِيثَ ابْنِ بُرَيْدَةَ ‏"‏ الْقُضَاةُ ثَلاَثَةٌ ‏"‏ ‏.‏\hadithno{3573}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Buraydah ibn al-Hasib: The Prophet (ﷺ) said: Judges are of three types, one of whom will go to Paradise and two to Hell. The one who will go to Paradise is a man who knows what is right and gives judgment accordingly; but a man who knows what is right and acts tyrannically in his judgment will go to Hell; and a man who gives judgment for people when he is ignorant will go to Hell. Abu Dawud said: On this subject this is the soundest tradition, that is, the tradition of Ibn Buraidah: Judges are of three types}}
\hadithdefcmd{abudawud}{3574}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - أَخْبَرَنِي يَزِيدُ بْنُ عَبْدِ اللَّهِ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ أَبِي قَيْسٍ، مَوْلَى عَمْرِو بْنِ الْعَاصِ عَنْ عَمْرِو بْنِ الْعَاصِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا حَكَمَ الْحَاكِمُ فَاجْتَهَدَ فَأَصَابَ فَلَهُ أَجْرَانِ وَإِذَا حَكَمَ فَاجْتَهَدَ فَأَخْطَأَ فَلَهُ أَجْرٌ ‏"‏ ‏.‏ فَحَدَّثْتُ بِهِ أَبَا بَكْرِ بْنَ حَزْمٍ فَقَالَ هَكَذَا حَدَّثَنِي أَبُو سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{3574}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7352) Sahih Muslim (1716)}\hadithtrans{It was narrated that `Amr bin Al-`As said "The Messenger of Allah said:'If a judge passes a judgment having exerted himself to arrive at what is correct, and he is indeed correct, he will have two rewards. If he passes judgment having exerted himself to arrive at what is correct, but it is incorrect, he will have one reward.'" I narrated it to Abu Bakr bin Hazm and he said: "This is what Abu Salamah narrated to me from Abu Hurairah}}
\hadithdefcmd{abudawud}{3575}{حَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا مُلاَزِمُ بْنُ عَمْرٍو، حَدَّثَنِي مُوسَى بْنُ نَجْدَةَ، عَنْ جَدِّهِ، يَزِيدَ بْنِ عَبْدِ الرَّحْمَنِ - وَهُوَ أَبُو كَثِيرٍ - قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ طَلَبَ قَضَاءَ الْمُسْلِمِينَ حَتَّى يَنَالَهُ ثُمَّ غَلَبَ عَدْلُهُ جَوْرَهُ فَلَهُ الْجَنَّةُ وَمَنْ غَلَبَ جَوْرُهُ عَدْلَهُ فَلَهُ النَّارُ ‏"‏ ‏.‏\hadithno{3575}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If anyone seeks the office of judge among Muslims till he gets it and his justice prevails over his tyranny, he will go to Paradise; but the man whose tyranny prevails over his justice will go to Hell}}
\hadithdefcmd{abudawud}{3576}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ بْنِ أَبِي يَحْيَى الرَّمْلِيُّ، حَدَّثَنَا زَيْدُ بْنُ أَبِي الزَّرْقَاءِ، حَدَّثَنَا ابْنُ أَبِي الزِّنَادِ، عَنْ أَبِيهِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏\{‏ وَمَنْ لَمْ يَحْكُمْ بِمَا أَنْزَلَ اللَّهُ فَأُولَئِكَ هُمُ الْكَافِرُونَ ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ الْفَاسِقُونَ ‏\}‏ هَؤُلاَءِ الآيَاتُ الثَّلاَثُ نَزَلَتْ فِي الْيَهُودِ خَاصَّةً فِي قُرَيْظَةَ وَالنَّضِيرِ ‏.‏\hadithno{3576}\hadithgrade{Al-Albani: Hasan Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn 'Abbas said:"If any do fail to judge (by the light of) what Allah has revealed, they are (no better than) unbelievers" up to "wrongdoers." These three verses were revealed about the Jews, particularly about Quraizah and al-Nadir}}
\hadithdefcmd{abudawud}{3577}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ رَجَاءٍ الأَنْصَارِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ بِشْرٍ الأَنْصَارِيِّ الأَزْرَقِ، قَالَ دَخَلَ رَجُلاَنِ مِنْ أَبْوَابِ كِنْدَةَ وَأَبُو مَسْعُودٍ الأَنْصَارِيُّ جَالِسٌ فِي حَلْقَةٍ فَقَالاَ أَلاَ رَجُلٌ يُنَفِّذُ بَيْنَنَا فَقَالَ رَجُلٌ مِنَ الْحَلْقَةِ أَنَا ‏.‏ فَأَخَذَ أَبُو مَسْعُودٍ كَفًّا مِنْ حَصًى فَرَمَاهُ بِهِ وَقَالَ مَهْ إِنَّهُ كَانَ يُكْرَهُ التَّسَرُّعُ إِلَى الْحُكْمِ ‏.‏\hadithno{3577}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{AbdurRahman ibn Bishr al-Ansari al-Azraq said:Two men from the locality of Kindah came while AbuMas'ud al-Ansari was sitting n a circle. They said: Is there any man who decides between us. A man from the circle said: I, AbuMas'ud took a handful of pebbles and threw at him, saying: Hush! It is disapproved to make haste in decision}}
\hadithdefcmd{abudawud}{3578}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا إِسْرَائِيلُ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ بِلاَلٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ طَلَبَ الْقَضَاءَ وَاسْتَعَانَ عَلَيْهِ وُكِلَ إِلَيْهِ وَمَنْ لَمْ يَطْلُبْهُ وَلَمْ يَسْتَعِنْ عَلَيْهِ أَنْزَلَ اللَّهُ مَلَكًا يُسَدِّدُهُ ‏"‏ ‏.‏ وَقَالَ وَكِيعٌ عَنْ إِسْرَائِيلَ عَنْ عَبْدِ الأَعْلَى عَنْ بِلاَلِ بْنِ أَبِي مُوسَى عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَقَالَ أَبُو عَوَانَةَ عَنْ عَبْدِ الأَعْلَى عَنْ بِلاَلِ بْنِ مِرْدَاسٍ الْفَزَارِيِّ عَنْ خَيْثَمَةَ الْبَصْرِيِّ عَنْ أَنَسٍ ‏.‏\hadithno{3578}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: If anyone desires the office of Judge and seeks help for it, he will be left to his own devices; if anyone does not desire it, nor does he seek help for it, Allah will send down an angel who will direct him aright. Waki' said: (This tradition has also been transmitted) by Isra'il, from 'Abd al-A'la, from Bilal bin Abi Musa, from Anas, from the Prophet (ﷺ). Abu 'Awanah said: from 'Abd al-A'la, from Bilal bin Mirdas al-Fazari, from Khaithamah al-Basri from Anas}}
\hadithdefcmd{abudawud}{3579}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، حَدَّثَنَا حُمَيْدُ بْنُ هِلاَلٍ، حَدَّثَنِي أَبُو بُرْدَةَ، قَالَ قَالَ أَبُو مُوسَى قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَنْ نَسْتَعْمِلَ - أَوْ لاَ نَسْتَعْمِلُ - عَلَى عَمَلِنَا مَنْ أَرَادَهُ ‏"‏ ‏.‏\hadithno{3579}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6923) Sahih Muslim (1824)}\hadithtrans{Abu Buradah reported the Prophet (ﷺ) as saying:"We will never employ or we shall not employ (the narrator is doubtful) in our work one who wants it}}
\hadithdefcmd{abudawud}{3580}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الْحَارِثِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الرَّاشِيَ وَالْمُرْتَشِيَ ‏.‏\hadithno{3580}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) cursed the one who bribes and the one who takes bribe}}
\hadithdefcmd{abudawud}{3581}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، حَدَّثَنِي قَيْسٌ، قَالَ حَدَّثَنِي عَدِيُّ بْنُ عُمَيْرَةَ الْكِنْدِيُّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ يَا أَيُّهَا النَّاسُ مَنْ عَمِلَ مِنْكُمْ لَنَا عَلَى عَمَلٍ فَكَتَمَنَا مِنْهُ مِخْيَطًا فَمَا فَوْقَهُ فَهُوَ غُلٌّ يَأْتِي بِهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ فَقَامَ رَجُلٌ مِنَ الأَنْصَارِ أَسْوَدُ كَأَنِّي أَنْظُرُ إِلَيْهِ فَقَالَ يَا رَسُولَ اللَّهِ اقْبَلْ عَنِّي عَمَلَكَ ‏.‏ قَالَ ‏"‏ وَمَا ذَاكَ ‏"‏ ‏.‏ قَالَ سَمِعْتُكَ تَقُولُ كَذَا وَكَذَا ‏.‏ قَالَ ‏"‏ وَأَنَا أَقُولُ ذَلِكَ مَنِ اسْتَعْمَلْنَاهُ عَلَى عَمَلٍ فَلْيَأْتِ بِقَلِيلِهِ وَكَثِيرِهِ فَمَا أُوتِيَ مِنْهُ أَخَذَهُ وَمَا نُهِيَ عَنْهُ انْتَهَى ‏"‏ ‏.‏\hadithno{3581}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1833)}\hadithtrans{Narrated Adi ibn Umayrah al-Kindi: The Prophet (ﷺ) said: O people, if any of you is put in an administrative post on our behalf and conceals from us a needle or more, he is acting unfaithfully, and will bring it on the Day of Resurrection. A black man from the Ansar, as if I am seeing him, stood and said: Messenger of Allah, take back from me my post. He asked: What is that? He replied: I heard you say such and such. He said: And I say that. If we appoint anyone to an office, he must bring what is connected with it, both little and much. What he is given, he may take, and he must refrain from what is kept away from him}}
\hadithdefcmd{abudawud}{3582}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، قَالَ أَخْبَرَنَا شَرِيكٌ، عَنْ سِمَاكٍ، عَنْ حَنَشٍ، عَنْ عَلِيٍّ، عَلَيْهِ السَّلاَمُ قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْيَمَنِ قَاضِيًا فَقُلْتُ يَا رَسُولَ اللَّهِ تُرْسِلُنِي وَأَنَا حَدِيثُ السِّنِّ وَلاَ عِلْمَ لِي بِالْقَضَاءِ فَقَالَ ‏ "‏ إِنَّ اللَّهَ سَيَهْدِي قَلْبَكَ وَيُثَبِّتُ لِسَانَكَ فَإِذَا جَلَسَ بَيْنَ يَدَيْكَ الْخَصْمَانِ فَلاَ تَقْضِيَنَّ حَتَّى تَسْمَعَ مِنَ الآخَرِ كَمَا سَمِعْتَ مِنَ الأَوَّلِ فَإِنَّهُ أَحْرَى أَنْ يَتَبَيَّنَ لَكَ الْقَضَاءُ ‏"‏ ‏.‏ قَالَ فَمَا زِلْتُ قَاضِيًا أَوْ مَا شَكَكْتُ فِي قَضَاءٍ بَعْدُ ‏.‏\hadithno{3582}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: The Messenger of Allah (ﷺ) sent me to the Yemen as judge, and I asked: Messenger of Allah, are you sending me when I am young and have no knowledge of the duties of a judge? He replied: Allah will guide your heart and keep your tongue true. When two litigants sit in front of you, do not decide till you hear what the other has to say as you heard what the first had to say; for it is best that you should have a clear idea of the best decision. He said: I had been a judge (for long); or he said (the narrator is doubtful): I have no doubts about a decision afterwards}}
\hadithdefcmd{abudawud}{3583}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا أَنَا بَشَرٌ وَإِنَّكُمْ تَخْتَصِمُونَ إِلَىَّ وَلَعَلَّ بَعْضَكُمْ أَنْ يَكُونَ أَلْحَنَ بِحُجَّتِهِ مِنْ بَعْضٍ فَأَقْضِيَ لَهُ عَلَى نَحْوِ مَا أَسْمَعُ مِنْهُ فَمَنْ قَضَيْتُ لَهُ مِنْ حَقِّ أَخِيهِ بِشَىْءٍ فَلاَ يَأْخُذْ مِنْهُ شَيْئًا فَإِنَّمَا أَقْطَعُ لَهُ قِطْعَةً مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{3583}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6967) Sahih Muslim (1713)}\hadithtrans{Umm Salamah reported the Messenger of Allah (ﷺ) as saying:"I am only a human being, and you bring your disputes to me, some perhaps being more eloquent in their plea than others, so that I give judgement on their behalf according to what I hear from them. Therefore, whatever I decide for anyone which by right belongs to his brother, he must not take anything, for I am granting him only a portion of Hell}}
\hadithdefcmd{abudawud}{3584}{حَدَّثَنَا الرَّبِيعُ بْنُ نَافِعٍ أَبُو تَوْبَةَ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ رَافِعٍ، مَوْلَى أُمِّ سَلَمَةَ عَنْ أُمِّ سَلَمَةَ، قَالَتْ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم رَجُلاَنِ يَخْتَصِمَانِ فِي مَوَارِيثَ لَهُمَا لَمْ تَكُنْ لَهُمَا بَيِّنَةٌ إِلاَّ دَعْوَاهُمَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم فَذَكَرَ مِثْلَهُ فَبَكَى الرَّجُلاَنِ وَقَالَ كُلُّ وَاحِدٍ مِنْهُمَا حَقِّي لَكَ ‏.‏ فَقَالَ لَهُمَا النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَمَّا إِذْ فَعَلْتُمَا مَا فَعَلْتُمَا فَاقْتَسِمَا وَتَوَخَّيَا الْحَقَّ ‏.‏ ثُمَّ اسْتَهِمَا ثُمَّ تَحَالاَّ ‏"‏ ‏.‏\hadithno{3584}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Umm Salamah said:Two men came to the Messenger of Allah (ﷺ) who were disputing over their inheritance. They had no evidence except their claim. The Prophet (ﷺ) then said in a similar way. Thereupon both the men wept and each of them said: This right of mine go to you. The Prophet (ﷺ) then said: Now you have done whatever you have done ; do divide it up, aiming at what is right, then drew lots, and let each of you consider the other to have what is legitimately his}}
\hadithdefcmd{abudawud}{3585}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عِيسَى، حَدَّثَنَا أُسَامَةُ، عَنْ عَبْدِ اللَّهِ بْنِ رَافِعٍ، قَالَ سَمِعْتُ أُمَّ سَلَمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ قَالَ يَخْتَصِمَانِ فِي مَوَارِيثَ وَأَشْيَاءَ قَدْ دَرَسَتْ فَقَالَ ‏ "‏ إِنِّي إِنَّمَا أَقْضِي بَيْنَكُمْ بِرَأْيِي فِيمَا لَمْ يُنْزَلْ عَلَىَّ فِيهِ ‏"‏ ‏.‏\hadithno{3585}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Umm Salamah reported the Prophet (ﷺ) as saying when two men were disputing over inheritance and old things:I decide between you on the basis of my opinion in cases about which no revelation has been sent down to me}}
\hadithdefcmd{abudawud}{3586}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، - رضى الله عنه - قَالَ وَهُوَ عَلَى الْمِنْبَرِ يَا أَيُّهَا النَّاسُ إِنَّ الرَّأْىَ إِنَّمَا كَانَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مُصِيبًا لأَنَّ اللَّهَ كَانَ يُرِيهِ وَإِنَّمَا هُوَ مِنَّا الظَّنُّ وَالتَّكَلُّفُ ‏.‏\hadithno{3586}\hadithgrade{Al-Albani: Daif Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Daif Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umar ibn al-Khattab: Umar said while he was (sitting) on the pulpit: O people, the opinion from the Messenger of Allah (ﷺ) was right, because Allah showed (i.e. inspired) him; but from us it is sheer conjecture and artifice}}
\hadithdefcmd{abudawud}{3587}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، أَخْبَرَنَا مُعَاذُ بْنُ مُعَاذٍ، قَالَ أَخْبَرَنِي أَبُو عُثْمَانَ الشَّامِيُّ، وَلاَ إِخَالُنِي رَأَيْتُ شَامِيًّا أَفْضَلَ مِنْهُ يَعْنِي حَرِيزَ بْنَ عُثْمَانَ ‏.‏\hadithno{3587}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Mu'adh bin Mu'adh said:Abu 'Uthman al-Shami, whose name is Hariz bin 'Uthman, told me. I think I did not see anyone from Syria better than him}}
\hadithdefcmd{abudawud}{3588}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، حَدَّثَنَا مُصْعَبُ بْنُ ثَابِتٍ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّ الْخَصْمَيْنِ يَقْعُدَانِ بَيْنَ يَدَىِ الْحَكَمِ ‏.‏\hadithno{3588}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn az-Zubayr: The Messenger of Allah (ﷺ) gave the decision that the two adversaries should be made to sit in front of the judge}}
\hadithdefcmd{abudawud}{3589}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، أَنَّهُ كَتَبَ إِلَى ابْنِهِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَقْضِي الْحَكَمُ بَيْنَ اثْنَيْنِ وَهُوَ غَضْبَانُ ‏"‏ ‏.‏\hadithno{3589}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (7158) Sahih Muslim (1717)}\hadithtrans{Abd al-Rahman bin Abi Bakrah reported on the authority of his father that he wrote to his son:The Messenger of Allah (ﷺ) said: A judge should not decide between the two while he is in anger}}
\hadithdefcmd{abudawud}{3590}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ، حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏\{‏ فَإِنْ جَاءُوكَ فَاحْكُمْ بَيْنَهُمْ أَوْ أَعْرِضْ عَنْهُمْ ‏\}‏ فَنُسِخَتْ قَالَ ‏\{‏ فَاحْكُمْ بَيْنَهُمْ بِمَا أَنْزَلَ اللَّهُ ‏\}‏ ‏.‏\hadithno{3590}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn 'Abbas said:The Qur'anic verse: "If they do come to thee, either judge between them, or decline to interfere" was abrogated by the verse: "So judge between them by what Allah hath revealed}}
\hadithdefcmd{abudawud}{3591}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ فَإِنْ جَاءُوكَ فَاحْكُمْ بَيْنَهُمْ أَوْ أَعْرِضْ عَنْهُمْ ‏\}‏ ‏\{‏ وَإِنْ حَكَمْتَ فَاحْكُمْ بَيْنَهُمْ بِالْقِسْطِ ‏\}‏ الآيَةَ قَالَ كَانَ بَنُو النَّضِيرِ إِذَا قَتَلُوا مِنْ بَنِي قُرَيْظَةَ أَدَّوْا نِصْفَ الدِّيَةِ وَإِذَا قَتَلَ بَنُو قُرَيْظَةَ مِنْ بَنِي النَّضِيرِ أَدَّوْا إِلَيْهِمُ الدِّيَةَ كَامِلَةً فَسَوَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَهُمْ ‏.‏\hadithno{3591}\hadithgrade{Al-Albani: Hasan Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: When this verse was revealed: "If they do come to thee, either judge between them, or decline to interfere....If thou judge, judge in equity between them." Banu an-Nadir used to pay half blood-money if they killed any-one from Banu Qurayzah. When Banu Qurayzah killed anyone from Banu an-Nadir, they would pay full blood-money. So the Messenger of Allah (ﷺ) made it equal between them}}
\hadithdefcmd{abudawud}{3592}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، عَنْ شُعْبَةَ، عَنْ أَبِي عَوْنٍ، عَنِ الْحَارِثِ بْنِ عَمْرِو بْنِ أَخِي الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنْ أُنَاسٍ، مِنْ أَهْلِ حِمْصَ مِنْ أَصْحَابِ مُعَاذِ بْنِ جَبَلٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا أَرَادَ أَنْ يَبْعَثَ مُعَاذًا إِلَى الْيَمَنِ قَالَ ‏"‏ كَيْفَ تَقْضِي إِذَا عَرَضَ لَكَ قَضَاءٌ ‏"‏ ‏.‏ قَالَ أَقْضِي بِكِتَابِ اللَّهِ ‏.‏ قَالَ ‏"‏ فَإِنْ لَمْ تَجِدْ فِي كِتَابِ اللَّهِ ‏"‏ ‏.‏ قَالَ فَبِسُنَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ ‏"‏ فَإِنْ لَمْ تَجِدْ فِي سُنَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ فِي كِتَابِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَجْتَهِدُ رَأْيِي وَلاَ آلُو ‏.‏ فَضَرَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم صَدْرَهُ وَقَالَ ‏"‏ الْحَمْدُ لِلَّهِ الَّذِي وَفَّقَ رَسُولَ رَسُولِ اللَّهِ لِمَا يُرْضِي رَسُولَ اللَّهِ ‏"‏ ‏.‏\hadithno{3592}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Some companions of Mu'adh ibn Jabal said:When the Messenger of Allah (ﷺ) intended to send Mu'adh ibn Jabal to the Yemen, he asked: How will you judge when the occasion of deciding a case arises? He replied: I shall judge in accordance with Allah's Book. He asked: (What will you do) if you do not find any guidance in Allah's Book? He replied: (I shall act) in accordance with the Sunnah of the Messenger of Allah (ﷺ). He asked: (What will you do) if you do not find any guidance in the Sunnah of the Messenger of Allah (ﷺ) and in Allah's Book? He replied: I shall do my best to form an opinion and I shall spare no effort. The Messenger of Allah (ﷺ) then patted him on the breast and said: Praise be to Allah Who has helped the messenger of the Messenger of Allah to find something which pleases the Messenger of Allah}}
\hadithdefcmd{abudawud}{3593}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، حَدَّثَنِي أَبُو عَوْنٍ، عَنِ الْحَارِثِ بْنِ عَمْرٍو، عَنْ نَاسٍ، مِنْ أَصْحَابِ مُعَاذٍ عَنْ مُعَاذِ بْنِ جَبَلٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا بَعَثَهُ إِلَى الْيَمَنِ فَذَكَرَ مَعْنَاهُ ‏.‏\hadithno{3593}\hadithgrade{Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Mu'adh bin Jabal said that when the Messenger of Allah (ﷺ) sent him to the Yemen... He then narrated the rest of the tradition to the same effect}}
\hadithdefcmd{abudawud}{3594}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ الْوَاحِدِ الدِّمَشْقِيُّ، حَدَّثَنَا مَرْوَانُ، - يَعْنِي ابْنَ مُحَمَّدٍ - حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، أَوْ عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ - شَكَّ الشَّيْخُ - عَنْ كَثِيرِ بْنِ زَيْدٍ، عَنِ الْوَلِيدِ بْنِ رَبَاحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الصُّلْحُ جَائِزٌ بَيْنَ الْمُسْلِمِينَ ‏"‏ ‏.‏ زَادَ أَحْمَدُ ‏"‏ إِلاَّ صُلْحًا أَحَلَّ حَرَامًا أَوْ حَرَّمَ حَلاَلاً ‏"‏ ‏.‏ وَزَادَ سُلَيْمَانُ بْنُ دَاوُدَ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْمُسْلِمُونَ عَلَى شُرُوطِهِمْ ‏"‏ ‏.‏\hadithno{3594}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Conciliation between Muslims is permissible. The narrator Ahmad added in his version: "except the conciliation which makes lawful unlawful and unlawful lawful." Sulayman ibn Dawud added: The Messenger of Allah (ﷺ) said: Muslims are on (i.e. stick to) their conditions}}
\hadithdefcmd{abudawud}{3595}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ كَعْبِ بْنِ مَالِكٍ، أَنَّ كَعْبَ بْنَ مَالِكٍ، أَخْبَرَهُ أَنَّهُ، تَقَاضَى ابْنَ أَبِي حَدْرَدٍ دَيْنًا كَانَ لَهُ عَلَيْهِ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ فَارْتَفَعَتْ أَصْوَاتُهُمَا حَتَّى سَمِعَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ فِي بَيْتِهِ فَخَرَجَ إِلَيْهِمَا رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى كَشَفَ سِجْفَ حُجْرَتِهِ وَنَادَى كَعْبَ بْنَ مَالِكٍ فَقَالَ ‏"‏ يَا كَعْبُ ‏"‏ ‏.‏ فَقَالَ لَبَّيْكَ يَا رَسُولَ اللَّهِ ‏.‏ فَأَشَارَ لَهُ بِيَدِهِ أَنْ ضَعِ الشَّطْرَ مِنْ دَيْنِكَ قَالَ كَعْبٌ قَدْ فَعَلْتُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قُمْ فَاقْضِهِ ‏"‏ ‏.‏\hadithno{3595}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (471) Sahih Muslim (1558)}\hadithtrans{Ka'b bin Malik said that in the time of the Messenger of Allah (ﷺ) he made demand in the mosque for payment of a debt due to him from Ibn Abi Hadrad, and their voices rose till the Messenger of Allah (ﷺ), who was in his house, heard them. The Messenger of Allah (ﷺ) then went out to them and, removing the curtain of his apartment, he called to Ka'b bin Malik, addressing:"Ka'b!" He said: "At your service, Messenger of Allah." Thereupon he made a gesture with is hand indicating: Remit half the debt due to you. Ka'b said: "I shall do so, Messenger of Allah." The Prophet (ﷺ) then said: "Get up and discharge}}
\hadithdefcmd{abudawud}{3596}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، وَأَحْمَدُ بْنُ السَّرْحِ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، أَنَّ أَبَاهُ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ عُثْمَانَ بْنِ عَفَّانَ أَخْبَرَهُ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ أَبِي عَمْرَةَ الأَنْصَارِيَّ أَخْبَرَهُ أَنَّ زَيْدَ بْنَ خَالِدٍ الْجُهَنِيَّ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ أُخْبِرُكُمْ بِخَيْرِ الشُّهَدَاءِ الَّذِي يَأْتِي بِشَهَادَتِهِ أَوْ يُخْبِرُ بِشَهَادَتِهِ قَبْلَ أَنْ يُسْأَلَهَا ‏"‏ ‏.‏ شَكَّ عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ أَيَّتَهُمَا قَالَ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ مَالِكٌ الَّذِي يُخْبِرُ بِشَهَادَتِهِ وَلاَ يَعْلَمُ بِهَا الَّذِي هِيَ لَهُ ‏.‏ قَالَ الْهَمْدَانِيُّ وَيَرْفَعُهَا إِلَى السُّلْطَانِ ‏.‏ قَالَ ابْنُ السَّرْحِ أَوْ يَأْتِي بِهَا الإِمَامَ ‏.‏ وَالإِخْبَارُ فِي حَدِيثِ الْهَمْدَانِيِّ ‏.‏ قَالَ ابْنُ السَّرْحِ ابْنَ أَبِي عَمْرَةَ ‏.‏ لَمْ يَقُلْ عَبْدَ الرَّحْمَنِ ‏.‏\hadithno{3596}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1719)}\hadithtrans{Zaid bin Khalid al-Juhani reported the Messenger of Allah (ﷺ) as saying:"Shall I not tell you of the best witnesses ? He is the one who produces his deposition or gives his evidence (the narrator is doubtful) before he is asked for it." 'Abd Allah bin Abi Bakr dobted which of them he said. Abu Dawud said: Malis said: This refers to a man gives his evidence, but he does not know for whom it is meant. Al-Hamdani said: "He should inform the authorities. Ibn al-Sarh said: "He should give it to the ruler. The work ikhbar (inform) occurs in the version of al-Hamdani." Ibn al-Sarh said: "Ibn Abi 'Amrah and not 'Abd al-Rahman}}
\hadithdefcmd{abudawud}{3597}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عُمَارَةُ بْنُ غَزِيَّةَ، عَنْ يَحْيَى بْنِ رَاشِدٍ، قَالَ جَلَسْنَا لِعَبْدِ اللَّهِ بْنِ عُمَرَ فَخَرَجَ إِلَيْنَا فَجَلَسَ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ حَالَتْ شَفَاعَتُهُ دُونَ حَدٍّ مِنْ حُدُودِ اللَّهِ فَقَدْ ضَادَّ اللَّهَ وَمَنْ خَاصَمَ فِي بَاطِلٍ وَهُوَ يَعْلَمُهُ لَمْ يَزَلْ فِي سَخَطِ اللَّهِ حَتَّى يَنْزِعَ عَنْهُ وَمَنْ قَالَ فِي مُؤْمِنٍ مَا لَيْسَ فِيهِ أَسْكَنَهُ اللَّهُ رَدْغَةَ الْخَبَالِ حَتَّى يَخْرُجَ مِمَّا قَالَ ‏"‏ ‏.‏\hadithno{3597}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Yahya ibn Rashid said:We were sitting waiting for Abdullah ibn Umar who came out to us and sat. He then said: I heard the Messenger of Allah (ﷺ) as saying: If anyone's intercession intervenes as an obstacle to one of the punishments prescribed by Allah, he has opposed Allah; if anyone disputes knowingly about something which is false, he remains in the displeasure of Allah till he desists, and if anyone makes an untruthful accusation against a Muslim, he will be made by Allah to dwell in the corrupt fluid flowing from the inhabitants of Hell till he retracts his statement}}
\hadithdefcmd{abudawud}{3598}{حَدَّثَنَا عَلِيُّ بْنُ الْحُسَيْنِ بْنِ إِبْرَاهِيمَ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عَاصِمُ بْنُ مُحَمَّدِ بْنِ زَيْدٍ الْعُمَرِيُّ، حَدَّثَنِي الْمُثَنَّى بْنُ يَزِيدَ، عَنْ مَطَرٍ الْوَرَّاقِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ قَالَ ‏ "‏ وَمَنْ أَعَانَ عَلَى خُصُومَةٍ بِظُلْمٍ فَقَدْ بَاءَ بِغَضَبٍ مِنَ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{3598}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn 'Umar from the Prophet (ﷺ) through different chain of narrators to the same effect. In this version he also said:"He who assits in a dispute unjustly deserves the anger of Allah, Most High}}
\hadithdefcmd{abudawud}{3599}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى الْبَلْخِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنِي سُفْيَانُ، - يَعْنِي الْعُصْفُرِيَّ - عَنْ أَبِيهِ، عَنْ حَبِيبِ بْنِ النُّعْمَانِ الأَسَدِيِّ، عَنْ خُرَيْمِ بْنِ فَاتِكٍ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الصُّبْحِ فَلَمَّا انْصَرَفَ قَامَ قَائِمًا فَقَالَ ‏"‏ عُدِلَتْ شَهَادَةُ الزُّورِ بِالإِشْرَاكِ بِاللَّهِ ‏"‏ ‏.‏ ثَلاَثَ مِرَارٍ ثُمَّ قَرَأَ ‏\{‏ فَاجْتَنِبُوا الرِّجْسَ مِنَ الأَوْثَانِ وَاجْتَنِبُوا قَوْلَ الزُّورِ * حُنَفَاءَ لِلَّهِ غَيْرَ مُشْرِكِينَ بِهِ ‏\}‏ ‏.‏\hadithno{3599}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Khuraym Ibn Fatik: The Messenger of Allah (ﷺ) offered the morning prayer. When he finished it, he stood up and said three times: False witness has been made equivalent to attributing a partner to Allah. He then recited: "So avoid the abomination of idols and avoid speaking falsehood as people pure of faith to Allah, not associating anything with Him}}
\hadithdefcmd{abudawud}{3600}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا مُحَمَّدُ بْنُ رَاشِدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ مُوسَى، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَدَّ شَهَادَةَ الْخَائِنِ وَالْخَائِنَةِ وَذِي الْغِمْرِ عَلَى أَخِيهِ وَرَدَّ شَهَادَةَ الْقَانِعِ لأَهْلِ الْبَيْتِ وَأَجَازَهَا لِغَيْرِهِمْ ‏.‏ قَالَ أَبُو دَاوُدَ الْغِمْرُ الْحِنَةُ وَالشَّحْنَاءُ وَالْقَانِعُ الأَجِيرُ التَّابِعُ مِثْلُ الأَجِيرِ الْخَاصِّ ‏.‏\hadithno{3600}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr bin Shu'aib on his father's authority told that his grandfather said:The Messenger of Allah (ﷺ) rejected the testimony of a deceitful man and woman, of one who harbours rancour against his brother, and he rejected the testimony of one who is dependent on a family, and he allowed his testimony for other. Abu Dawud said: Ghimr means malice and enimity ; qani (dependant), a subordinate servant like a special servant}}
\hadithdefcmd{abudawud}{3601}{حَدَّثَنَا مُحَمَّدُ بْنُ خَلَفِ بْنِ طَارِقٍ الرَّازِيُّ، حَدَّثَنَا زَيْدُ بْنُ يَحْيَى بْنِ عُبَيْدٍ الْخُزَاعِيُّ، حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الْعَزِيزِ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، بِإِسْنَادِهِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَجُوزُ شَهَادَةُ خَائِنٍ وَلاَ خَائِنَةٍ وَلاَ زَانٍ وَلاَ زَانِيَةٍ وَلاَ ذِي غِمْرٍ عَلَى أَخِيهِ ‏"‏ ‏.‏\hadithno{3601}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above (No. 3593) has also been transmitted by Sulayman ibn Musa through a different chain of narrators. This version has:The Messenger of Allah (ﷺ) said: The testimony of a deceitful man or woman, of an adulterer and adulteress, and of one who harbours rancour against his brother is not allowable}}
\hadithdefcmd{abudawud}{3602}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يَحْيَى بْنُ أَيُّوبَ، وَنَافِعُ بْنُ يَزِيدَ، عَنِ ابْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَجُوزُ شَهَادَةُ بَدَوِيٍّ عَلَى صَاحِبِ قَرْيَةٍ ‏"‏ ‏.‏\hadithno{3602}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: The testimony of a nomad Arab against a townsman is not allowable}}
\hadithdefcmd{abudawud}{3603}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، حَدَّثَنِي عُقْبَةُ بْنُ الْحَارِثِ، وَحَدَّثَنِيهِ صَاحِبٌ، لِي عَنْهُ - وَأَنَا لِحَدِيثِ، صَاحِبِي أَحْفَظُ - قَالَ تَزَوَّجْتُ أُمَّ يَحْيَى بِنْتَ أَبِي إِهَابٍ فَدَخَلَتْ عَلَيْنَا امْرَأَةٌ سَوْدَاءُ فَزَعَمَتْ أَنَّهَا أَرْضَعَتْنَا جَمِيعًا فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ فَأَعْرَضَ عَنِّي فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّهَا لَكَاذِبَةٌ ‏.‏ قَالَ ‏ "‏ وَمَا يُدْرِيكَ وَقَدْ قَالَتْ مَا قَالَتْ دَعْهَا عَنْكَ ‏"‏ ‏.‏\hadithno{3603}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5104)}\hadithtrans{Uqbah bin al-Harith said:"I married Umm Yahya daughter of Abu Ihab. A black woman entered upon us. She said that she had suckled both of us. So I came to the Prophet (ﷺ), and amentioned it to him. He turned away from me. I said (to him): Messenger of Allah! she is a liar. He said: What do you know? She has said what she has said. Separate yourself from her (wife)}}
\hadithdefcmd{abudawud}{3604}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ الْحَرَّانِيُّ، حَدَّثَنَا الْحَارِثُ بْنُ عُمَيْرٍ الْبَصْرِيُّ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، كِلاَهُمَا عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عُبَيْدِ بْنِ أَبِي مَرْيَمَ، عَنْ عُقْبَةَ بْنِ الْحَارِثِ، - وَقَدْ سَمِعْتُهُ مِنْ، عُقْبَةَ وَلَكِنِّي لِحَدِيثِ عُبَيْدٍ أَحْفَظُ - فَذَكَرَ مَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ نَظَرَ حَمَّادُ بْنُ زَيْدٍ إِلَى الْحَارِثِ بْنِ عُمَيْرٍ فَقَالَ هَذَا مِنْ ثِقَاتِ أَصْحَابِ أَيُّوبَ ‏.‏\hadithno{3604}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by 'Uqbah bin al-Harith to the same effect through a different chain of narrators. Abu Dawud said:Hammad bin Zaid looked at al-Harith bin 'Umair and said: He is from reliable narrators from Ayyub}}
\hadithdefcmd{abudawud}{3605}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا زَكَرِيَّا، عَنِ الشَّعْبِيِّ، أَنَّ رَجُلاً، مِنَ الْمُسْلِمِينَ حَضَرَتْهُ الْوَفَاةُ بِدَقُوقَاءَ هَذِهِ وَلَمْ يَجِدْ أَحَدًا مِنَ الْمُسْلِمِينَ يُشْهِدُهُ عَلَى وَصِيَّتِهِ فَأَشْهَدَ رَجُلَيْنِ مِنْ أَهْلِ الْكِتَابِ فَقَدِمَا الْكُوفَةَ فَأَتَيَا أَبَا مُوسَى الأَشْعَرِيَّ فَأَخْبَرَاهُ وَقَدِمَا بِتَرِكَتِهِ وَوَصِيَّتِهِ ‏.‏ فَقَالَ الأَشْعَرِيُّ هَذَا أَمْرٌ لَمْ يَكُنْ بَعْدَ الَّذِي كَانَ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَأَحْلَفَهُمَا بَعْدَ الْعَصْرِ بِاللَّهِ مَا خَانَا وَلاَ كَذِبَا وَلاَ بَدَّلاَ وَلاَ كَتَمَا وَلاَ غَيَّرَا وَإِنَّهَا لَوَصِيَّةُ الرَّجُلِ وَتَرِكَتُهُ فَأَمْضَى شَهَادَتَهُمَا ‏.‏\hadithno{3605}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ash-Sha'bi said:A Muslim was about to die at Daquqa', but he did not find any Muslim to call him for witness to his will. So he called two men of the people of the Book for witness. Then they came to Kufah, and approaching AbuMusa al-Ash'ari they informed him (about his) will. They brought his inheritance and will. Al-Ash'ari said: This is an incident (like) which happened in the time of the Messenger of Allah (ﷺ) and never occurred after him. So he made them to swear by Allah after the afternoon prayer to the effect that they had not misappropriated, nor told a lie, nor changed, nor concealed, nor altered, and that it was the will of the man and his inheritance. He then executed their witness}}
\hadithdefcmd{abudawud}{3606}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ مُحَمَّدِ بْنِ أَبِي الْقَاسِمِ، عَنْ عَبْدِ الْمَلِكِ بْنِ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ خَرَجَ رَجُلٌ مِنْ بَنِي سَهْمٍ مَعَ تَمِيمٍ الدَّارِيِّ وَعَدِيِّ بْنِ بَدَّاءَ فَمَاتَ السَّهْمِيُّ بِأَرْضٍ لَيْسَ بِهَا مُسْلِمٌ فَلَمَّا قَدِمَا بِتَرِكَتِهِ فَقَدُوا جَامَ فِضَّةٍ مُخَوَّصًا بِالذَّهَبِ فَأَحْلَفَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ وُجِدَ الْجَامُ بِمَكَّةَ فَقَالُوا اشْتَرَيْنَاهُ مِنْ تَمِيمٍ وَعَدِيٍّ فَقَامَ رَجُلاَنِ مِنْ أَوْلِيَاءِ السَّهْمِيِّ فَحَلَفَا لَشَهَادَتُنَا أَحَقُّ مِنْ شَهَادَتِهِمَا وَإِنَّ الْجَامَ لِصَاحِبِهِمْ ‏.‏ قَالَ فَنَزَلَتْ فِيهِمْ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا شَهَادَةُ بَيْنِكُمْ إِذَا حَضَرَ أَحَدَكُمُ الْمَوْتُ ‏\}‏ الآيَةَ ‏.‏\hadithno{3606}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2780)}\hadithtrans{Narrated Abdullah Ibn Abbas: A man from Banu Sahm went out with Tamim ad-Dari and Adi ibn Badda'. The man of Banu Sahm died in the land where no Muslim was present. When they returned with his inheritance, they (the heirs) did not find a silver cup with lines of gold (in his property). The Messenger of Allah (ﷺ) administered on oath to them. The cup was then found (with someone) at Mecca. They said: We have bought it from Tamim and Adi. Then two men from the heirs of the man of Banu Sahm got up and swore saying: Our witness is more reliable than their witness. They said that the cup belonged to their man. He (Ibn Abbas) said: The following verse was revealed about them: "O ye who believe! when death approaches any of you}}
\hadithdefcmd{abudawud}{3607}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، أَنَّ الْحَكَمَ بْنَ نَافِعٍ، حَدَّثَهُمْ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، عَنْ عُمَارَةَ بْنِ خُزَيْمَةَ، أَنَّ عَمَّهُ، حَدَّثَهُ وَهُوَ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم ابْتَاعَ فَرَسًا مِنْ أَعْرَابِيٍّ فَاسْتَتْبَعَهُ النَّبِيُّ صلى الله عليه وسلم لِيَقْضِيَهُ ثَمَنَ فَرَسِهِ فَأَسْرَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَشْىَ وَأَبْطَأَ الأَعْرَابِيُّ فَطَفِقَ رِجَالٌ يَعْتَرِضُونَ الأَعْرَابِيَّ فَيُسَاوِمُونَهُ بِالْفَرَسِ وَلاَ يَشْعُرُونَ أَنَّ النَّبِيَّ صلى الله عليه وسلم ابْتَاعَهُ فَنَادَى الأَعْرَابِيُّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنْ كُنْتَ مُبْتَاعًا هَذَا الْفَرَسَ وَإِلاَّ بِعْتُهُ ‏.‏ فَقَامَ النَّبِيُّ صلى الله عليه وسلم حِينَ سَمِعَ نِدَاءَ الأَعْرَابِيِّ فَقَالَ ‏"‏ أَوَلَيْسَ قَدِ ابْتَعْتُهُ مِنْكَ ‏"‏ ‏.‏ فَقَالَ الأَعْرَابِيُّ لاَ وَاللَّهِ مَا بِعْتُكَهُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بَلَى قَدِ ابْتَعْتُهُ مِنْكَ ‏"‏ ‏.‏ فَطَفِقَ الأَعْرَابِيُّ يَقُولُ هَلُمَّ شَهِيدًا ‏.‏ فَقَالَ خُزَيْمَةُ بْنُ ثَابِتٍ أَنَا أَشْهَدُ أَنَّكَ قَدْ بَايَعْتَهُ ‏.‏ فَأَقْبَلَ النَّبِيُّ صلى الله عليه وسلم عَلَى خُزَيْمَةَ فَقَالَ ‏"‏ بِمَ تَشْهَدُ ‏"‏ ‏.‏ فَقَالَ بِتَصْدِيقِكَ يَا رَسُولَ اللَّهِ ‏.‏ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَهَادَةَ خُزَيْمَةَ بِشَهَادَةِ رَجُلَيْنِ ‏.‏\hadithno{3607}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Uncle of Umarah ibn Khuzaymah: The Prophet (ﷺ) bought a horse from a Bedouin. The Prophet (ﷺ) took him with him to pay him the price of his horse. The Messenger of Allah (ﷺ) walked quickly and the Bedouin walked slowly. The people stopped the Bedouin and began to bargain with him for the horse as and they did not know that the Prophet (ﷺ) had bought it. The Bedouin called the Messenger of Allah (ﷺ) saying: If you want this horse, (then buy it), otherwise I shall sell it. The Prophet (ﷺ) stopped when he heard the call of the Bedouin, and said: Have I not bought it from you? The Bedouin said: I swear by Allah, I have not sold it to you. The Prophet (ﷺ) said: Yes, I have bought it from you. The Bedouin began to say: Bring a witness. Khuzaymah ibn Thabit then said: I bear witness that you have bought it. The Prophet (ﷺ) turned to Khuzaymah and said: On what (grounds) do you bear witness? He said: By considering you trustworthy, Messenger of Allah (ﷺ)! The Prophet (ﷺ) made the witness of Khuzaymah equivalent to the witness of two people}}
\hadithdefcmd{abudawud}{3608}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَالْحَسَنُ بْنُ عَلِيٍّ، أَنَّ زَيْدَ بْنَ الْحُبَابِ، حَدَّثَهُمْ حَدَّثَنَا سَيْفٌ الْمَكِّيُّ، - قَالَ عُثْمَانُ سَيْفُ بْنُ سُلَيْمَانَ - عَنْ قَيْسِ بْنِ سَعْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى بِيَمِينٍ وَشَاهِدٍ ‏.‏\hadithno{3608}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1712)}\hadithtrans{Ibn 'Abbas said:The Messenger of Allah (ﷺ) gave a decision on the basis of an oath and a single witness}}
\hadithdefcmd{abudawud}{3609}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَسَلَمَةُ بْنُ شَبِيبٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مُحَمَّدُ بْنُ مُسْلِمٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، بِإِسْنَادِهِ وَمَعْنَاهُ ‏.‏ قَالَ سَلَمَةُ فِي حَدِيثِهِ قَالَ عَمْرٌو فِي الْحُقُوقِ ‏.‏\hadithno{3609}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by 'Amr bin Dinar through a different chain of narrators and to the same effect. Salamah has in his version:'Amr said: In the rights (of the people)}}
\hadithdefcmd{abudawud}{3610}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي بَكْرٍ أَبُو مُصْعَبٍ الزُّهْرِيُّ، حَدَّثَنَا الدَّرَاوَرْدِيُّ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى بِالْيَمِينِ مَعَ الشَّاهِدِ ‏.‏ قَالَ أَبُو دَاوُدَ وَزَادَنِي الرَّبِيعُ بْنُ سُلَيْمَانَ الْمُؤَذِّنُ فِي هَذَا الْحَدِيثِ قَالَ أَخْبَرَنِي الشَّافِعِيُّ عَنْ عَبْدِ الْعَزِيزِ قَالَ فَذَكَرْتُ ذَلِكَ لِسُهَيْلٍ فَقَالَ أَخْبَرَنِي رَبِيعَةُ - وَهُوَ عِنْدِي ثِقَةٌ - أَنِّي حَدَّثْتُهُ إِيَّاهُ وَلاَ أَحْفَظُهُ ‏.‏ قَالَ عَبْدُ الْعَزِيزِ وَقَدْ كَانَ أَصَابَتْ سُهَيْلاً عِلَّةٌ أَذْهَبَتْ بَعْضَ عَقْلِهِ وَنَسِيَ بَعْضَ حَدِيثِهِ فَكَانَ سُهَيْلٌ بَعْدُ يُحَدِّثُهُ عَنْ رَبِيعَةَ عَنْهُ عَنْ أَبِيهِ ‏.‏\hadithno{3610}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) gave a decision on the basis of an oath and a single witness. Abu Dawud said: Al-Rabi' bin Sulaiman al-Mu'adhdhin told me some additional words in this tradition: Al-Shafi'i told me from 'Abd al-'Aziz. I then mentioned it fo Suhail who said: Rabi'ah told me - and he is reliable in my opinion - that I told him this (tradition) and I do not remember it. 'Abd al-'Aziz said: Suhail suffered from some disease which caused him to lose a little of his intelligence, and he forgot some of his traditions. Thereafter Suhail would narrate traditions from Rabi'ah on the authority of his father}}
\hadithdefcmd{abudawud}{3611}{حَدَّثَنَا مُحَمَّدُ بْنُ دَاوُدَ الإِسْكَنْدَرَانِيُّ، حَدَّثَنَا زِيَادٌ، - يَعْنِي ابْنَ يُونُسَ - حَدَّثَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ رَبِيعَةَ، بِإِسْنَادِ أَبِي مُصْعَبٍ وَمَعْنَاهُ ‏.‏ قَالَ سُلَيْمَانُ فَلَقِيتُ سُهَيْلاً فَسَأَلْتُهُ عَنْ هَذَا الْحَدِيثِ فَقَالَ مَا أَعْرِفُهُ ‏.‏ فَقُلْتُ لَهُ إِنَّ رَبِيعَةَ أَخْبَرَنِي بِهِ عَنْكَ ‏.‏ قَالَ فَإِنْ كَانَ رَبِيعَةُ أَخْبَرَكَ عَنِّي فَحَدِّثْ بِهِ عَنْ رَبِيعَةَ عَنِّي ‏.‏\hadithno{3611}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Rabi'ah through the chain of Abu Mus'ab and to the same effect. Sulaiman said:I then met Suhail and asked him about this tradition. He said: I do not know it. I said to him: Rabi'ah transmitted it to me from you. He said: If Rabi'ah transmitted it to you from me, then retransmit it from Rabi'ah on my authority}}
\hadithdefcmd{abudawud}{3612}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا عَمَّارُ بْنُ شُعَيْبِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْبِ الْعَنْبَرِيُّ، حَدَّثَنِي أَبِي قَالَ، سَمِعْتُ جَدِّيَ الزُّبَيْبَ، يَقُولُ بَعَثَ نَبِيُّ اللَّهِ صلى الله عليه وسلم جَيْشًا إِلَى بَنِي الْعَنْبَرِ فَأَخَذُوهُمْ بِرُكْبَةٍ مِنْ نَاحِيَةِ الطَّائِفِ فَاسْتَاقُوهُمْ إِلَى نَبِيِّ اللَّهِ صلى الله عليه وسلم فَرَكِبْتُ فَسَبَقْتُهُمْ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقُلْتُ السَّلاَمُ عَلَيْكَ يَا نَبِيَّ اللَّهِ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ أَتَانَا جُنْدُكَ فَأَخَذُونَا وَقَدْ كُنَّا أَسْلَمْنَا وَخَضْرَمْنَا آذَانَ النَّعَمِ فَلَمَّا قَدِمَ بَلْعَنْبَرُ قَالَ لِي نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ لَكُمْ بَيِّنَةٌ عَلَى أَنَّكُمْ أَسْلَمْتُمْ قَبْلَ أَنْ تُؤْخَذُوا فِي هَذِهِ الأَيَّامِ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ مَنْ بَيِّنَتُكَ ‏"‏ ‏.‏ قُلْتُ سَمُرَةُ رَجُلٌ مِنْ بَنِي الْعَنْبَرِ وَرَجُلٌ آخَرُ سَمَّاهُ لَهُ فَشَهِدَ الرَّجُلُ وَأَبَى سَمُرَةُ أَنْ يَشْهَدَ فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ قَدْ أَبَى أَنْ يَشْهَدَ لَكَ فَتَحْلِفُ مَعَ شَاهِدِكَ الآخَرِ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ فَاسْتَحْلَفَنِي فَحَلَفْتُ بِاللَّهِ لَقَدْ أَسْلَمْنَا يَوْمَ كَذَا وَكَذَا وَخَضْرَمْنَا آذَانَ النَّعَمِ ‏.‏ فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ اذْهَبُوا فَقَاسِمُوهُمْ أَنْصَافَ الأَمْوَالِ وَلاَ تَمَسُّوا ذَرَارِيَهُمْ لَوْلاَ أَنَّ اللَّهَ لاَ يُحِبُّ ضَلاَلَةَ الْعَمَلِ مَا رَزَيْنَاكُمْ عِقَالاً ‏"‏ ‏.‏ قَالَ الزُّبَيْبُ فَدَعَتْنِي أُمِّي فَقَالَتْ هَذَا الرَّجُلُ أَخَذَ زِرْبِيَّتِي فَانْصَرَفْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم - يَعْنِي فَأَخْبَرْتُهُ - فَقَالَ لِي ‏"‏ احْبِسْهُ ‏"‏ ‏.‏ فَأَخَذْتُ بِتَلْبِيبِهِ وَقُمْتُ مَعَهُ مَكَانَنَا ثُمَّ نَظَرَ إِلَيْنَا نَبِيُّ اللَّهِ صلى الله عليه وسلم قَائِمَيْنِ فَقَالَ ‏"‏ مَا تُرِيدُ بِأَسِيرِكَ ‏"‏ ‏.‏ فَأَرْسَلْتُهُ مِنْ يَدِي فَقَامَ نَبِيُّ اللَّهِ صلى الله عليه وسلم فَقَالَ لِلرَّجُلِ ‏"‏ رُدَّ عَلَى هَذَا زِرْبِيَّةَ أُمِّهِ الَّتِي أَخَذْتَ مِنْهَا ‏"‏ ‏.‏ فَقَالَ يَا نَبِيَّ اللَّهِ إِنَّهَا خَرَجَتْ مِنْ يَدِي ‏.‏ قَالَ فَاخْتَلَعَ نَبِيُّ اللَّهِ صلى الله عليه وسلم سَيْفَ الرَّجُلِ فَأَعْطَانِيهِ ‏.‏ وَقَالَ لِلرَّجُلِ ‏"‏ اذْهَبْ فَزِدْهُ آصُعًا مِنْ طَعَامٍ ‏"‏ ‏.‏ قَالَ فَزَادَنِي آصُعًا مِنْ شَعِيرٍ ‏.‏\hadithno{3612}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Zubayb ibn Tha'labah al-Anbari: The Messenger of Allah (ﷺ) sent an army to Banu al-Anbar. They captured them at Rukbah in the suburbs of at-Ta'if and drove them to the Holy Prophet (ﷺ). I rode hurriedly to the Holy Prophet (ﷺ) and said: Peace be on you, Messenger of Allah, and the mercy of Allah and His blessings. Your contingent came to us and arrested us, but we had already embraced Islam and cut the sides of the ears of our cattle. When Banu al-Anbar arrived, the Holy Prophet (ﷺ) said to me: Have you any evidence that you had embraced Islam before you were captured today? I said: Yes. He said: Who is your witness? I said: Samurah, a man from Banu al-Anbar, and another man whom he named. The man testified but Samurah refused to testify. The Holy Prophet (ﷺ) said: He (Samurah) has refused to testify for you, so take an oath with your other witness. I said: Yes. He then dictated an oath to me and I swore to the effect that we had embraced Islam on a certain day, and that we had cut the sides of the ears of the cattle. The Holy Prophet (ﷺ) said: Go and divide half of their property, but do not touch their children. Had Allah not disliked the wastage of action, we should not have taxed you even a rope. Zubayb said: My mother called me and said: This man has taken my mattress. I then went to the Holy Prophet (ﷺ) and informed him. He said to me: Detain him. So I caught him with a garment around his neck, and stood there with him . Then the Holy Prophet (ﷺ) looked at us standing there. He asked: What do you intend (doing) with your captive? I said: I shall let him go free if he returns to this (man) the mattress of his mother which he has taken from her. He said: Prophet of Allah (ﷺ), I no longer have it. He said: The Holy Prophet (ﷺ) took the sword of the man and gave it to me, and said to him: Go and give him some sa's of cereal. So he gave me some sa's of barley}}
\hadithdefcmd{abudawud}{3613}{حَدَّثَنَا مُحَمَّدُ بْنُ مِنْهَالٍ الضَّرِيرُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا ابْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ أَبِي مُوسَى الأَشْعَرِيِّ، أَنَّ رَجُلَيْنِ، ادَّعَيَا بَعِيرًا أَوْ دَابَّةً إِلَى النَّبِيِّ صلى الله عليه وسلم لَيْسَتْ لِوَاحِدٍ مِنْهُمَا بَيِّنَةٌ فَجَعَلَهُ النَّبِيُّ صلى الله عليه وسلم بَيْنَهُمَا ‏.‏\hadithno{3613}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuMusa al-Ash'ari: Two men claimed a camel or an animal and brought the case to the Holy Prophet (ﷺ). But as neither of them produced any proof, the Holy Prophet (ﷺ) declared that they should share it equally}}
\hadithdefcmd{abudawud}{3614}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ سَعِيدٍ، بِإِسْنَادِهِ وَمَعْنَاهُ ‏.‏\hadithno{3614}\hadithgrade{Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Sa'id through a different chain of narrators to the same effect}}
\hadithdefcmd{abudawud}{3615}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، بِمَعْنَى إِسْنَادِهِ أَنَّ رَجُلَيْنِ، ادَّعَيَا بَعِيرًا عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَبَعَثَ كُلُّ وَاحِدٍ مِنْهُمَا شَاهِدَيْنِ فَقَسَمَهُ النَّبِيُّ صلى الله عليه وسلم بَيْنَهُمَا نِصْفَيْنِ ‏.‏\hadithno{3615}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Qatadah through a different chain of narrators to the effect that two men laid claim camel and both of them produced witness so the prophet (peace be upon him) divided it in halves between them}}
\hadithdefcmd{abudawud}{3616}{حَدَّثَنَا مُحَمَّدُ بْنُ مِنْهَالٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا ابْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ خِلاَسٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلَيْنِ، اخْتَصَمَا فِي مَتَاعٍ إِلَى النَّبِيِّ صلى الله عليه وسلم لَيْسَ لِوَاحِدٍ مِنْهُمَا بَيِّنَةٌ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اسْتَهِمَا عَلَى الْيَمِينِ مَا كَانَ أَحَبَّا ذَلِكَ أَوْ كَرِهَا ‏"‏ ‏.‏\hadithno{3616}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: Two men disputed about some property and brought the case to the Holy Prophet (ﷺ), but neither of them could produce any proof. So the Holy Prophet (ﷺ) said: Cast lots about the oath whatever it may be, whether they like it or dislike it}}
\hadithdefcmd{abudawud}{3617}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَسَلَمَةُ بْنُ شَبِيبٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، - قَالَ أَحْمَدُ قَالَ - حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَرِهَ الاِثْنَانِ الْيَمِينَ أَوِ اسْتَحَبَّاهَا فَلْيَسْتَهِمَا عَلَيْهَا ‏"‏ ‏.‏ قَالَ سَلَمَةُ قَالَ أَخْبَرَنَا مَعْمَرٌ وَقَالَ إِذَا أُكْرِهَ الاِثْنَانِ عَلَى الْيَمِينِ ‏.‏\hadithno{3617}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu hurairah reported the holy prophet (peace be upon him) as saying:When two men dislike the oath or like it,lots will be cost about it. Salamah said on the authority of Ma’mar who said: when the two are compelled to take an oath}}
\hadithdefcmd{abudawud}{3618}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، بِإِسْنَادِ ابْنِ مِنْهَالٍ مِثْلَهُ قَالَ فِي دَابَّةٍ وَلَيْسَ لَهُمَا بَيِّنَةٌ فَأَمَرَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَسْتَهِمَا عَلَى الْيَمِينِ ‏.‏\hadithno{3618}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by sa’id b. ‘Urubah through the chain as narrated by Ibn Minhal. This version has :About an animal and they had no proof. So the Messenger of Allah (ﷺ) ordered to cast lots about the oath}}
\hadithdefcmd{abudawud}{3619}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا نَافِعُ بْنُ عُمَرَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ كَتَبَ إِلَىَّ ابْنُ عَبَّاسٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى بِالْيَمِينِ عَلَى الْمُدَّعَى عَلَيْهِ ‏.‏\hadithno{3619}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2514، 1711)}\hadithtrans{Ibn Abi Mulaikah said:Ibn ‘Abbas wrote to me that the Messenger of Allah (ﷺ)had defendant should take an oath}}
\hadithdefcmd{abudawud}{3620}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا عَطَاءُ بْنُ السَّائِبِ، عَنْ أَبِي يَحْيَى، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ - يَعْنِي لِرَجُلٍ حَلَّفَهُ - ‏ "‏ احْلِفْ بِاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ مَا لَهُ عِنْدَكَ شَىْءٌ ‏"‏ ‏.‏ يَعْنِي لِلْمُدَّعِي ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو يَحْيَى اسْمُهُ زِيَادٌ كُوفِيٌّ ثِقَةٌ ‏.‏\hadithno{3620}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Holy Prophet (ﷺ) said to a man whom he asked to take an oath: Swear by Allah except whom there is no god that you have nothing belonging to him, i.e. the plaintiff}}
\hadithdefcmd{abudawud}{3621}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنِ الأَشْعَثِ، قَالَ كَانَ بَيْنِي وَبَيْنَ رَجُلٍ مِنَ الْيَهُودِ أَرْضٌ فَجَحَدَنِي فَقَدَّمْتُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ لِيَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَلَكَ بَيِّنَةٌ ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ قَالَ لِلْيَهُودِيِّ ‏"‏ احْلِفْ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِذًا يَحْلِفَ وَيَذْهَبَ بِمَالِي ‏.‏ فَأَنْزَلَ اللَّهُ ‏\{‏ إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ‏\}‏ إِلَى آخِرِ الآيَةِ ‏.‏\hadithno{3621}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2616، 2617) Sahih Muslim (138)}\hadithtrans{Al-Ash’ath b. Qais said:A Jew and I shared some land and he denied my right, so I took him to the holy prophet (ﷺ). The holy prophet (ﷺ) said to me: Have you have proof. I said: No. He then said to the Jew: Swear an oath I said Messenger of Allah,he will swear an oath and go off my property. So Allah sent down: “Those who barter for a small price Allah’s covenant and their oaths...." to the end of the verse}}
\hadithdefcmd{abudawud}{3622}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا الْفِرْيَابِيُّ، حَدَّثَنَا الْحَارِثُ بْنُ سُلَيْمَانَ، حَدَّثَنِي كُرْدُوسٌ، عَنِ الأَشْعَثِ بْنِ قَيْسٍ، أَنَّ رَجُلاً، مِنْ كِنْدَةَ وَرَجُلاً مِنْ حَضْرَمَوْتَ اخْتَصَمَا إِلَى النَّبِيِّ صلى الله عليه وسلم فِي أَرْضٍ مِنَ الْيَمَنِ فَقَالَ الْحَضْرَمِيُّ يَا رَسُولَ اللَّهِ إِنَّ أَرْضِي اغْتَصَبَنِيهَا أَبُو هَذَا وَهِيَ فِي يَدِهِ ‏.‏ قَالَ ‏ "‏ هَلْ لَكَ بَيِّنَةٌ ‏"‏ ‏.‏ قَالَ لاَ وَلَكِنْ أُحَلِّفُهُ وَاللَّهِ مَا يَعْلَمُ أَنَّهَا أَرْضِي اغْتَصَبَنِيهَا أَبُوهُ ‏.‏ فَتَهَيَّأَ الْكِنْدِيُّ يَعْنِي لِلْيَمِينِ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{3622}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Al-Ash’ath b. Qais said:A men from Kindah and a men from Hadramawt came to the Holy Prophet(ﷺ)with their dispute about a land in the Yemen. The Hadrami said: Messenger of Allah, the this (man)had usurped land belonging to me, and it is his possession. He asked: Have you any proof ?He replied:No, but I can have him swear on oath. Allah knows that it is my land, and father seized it from me. The Kindi was prepared to take oath. He then narrated the rest of the tradition}}
\hadithdefcmd{abudawud}{3623}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ عَلْقَمَةَ بْنِ وَائِلِ بْنِ حُجْرٍ الْحَضْرَمِيِّ، عَنْ أَبِيهِ، قَالَ جَاءَ رَجُلٌ مِنْ حَضْرَمَوْتَ وَرَجُلٌ مِنْ كِنْدَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ الْحَضْرَمِيُّ يَا رَسُولَ اللَّهِ إِنَّ هَذَا غَلَبَنِي عَلَى أَرْضٍ كَانَتْ لأَبِي فَقَالَ الْكِنْدِيُّ هِيَ أَرْضِي فِي يَدِي أَزْرَعُهَا لَيْسَ لَهُ فِيهَا حَقٌّ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم لِلْحَضْرَمِيِّ ‏"‏ أَلَكَ بَيِّنَةٌ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَلَكَ يَمِينُهُ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّهُ فَاجِرٌ لَيْسَ يُبَالِي مَا حَلَفَ لَيْسَ يَتَوَرَّعُ مِنْ شَىْءٍ ‏.‏ فَقَالَ ‏"‏ لَيْسَ لَكَ مِنْهُ إِلاَّ ذَلِكَ ‏"‏ ‏.‏\hadithno{3623}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (139)}\hadithtrans{‘Alqamah b. Wa’il b. Hujr al-Hadrami said on the authority of the father:A man from Hadramaw and a man from kindah came to the Messenger of Allah (ﷺ). The hadrami said: Messenger of Allah, this (man) has seized land which belonged to my father. Al-Kindi said: That is my land in my possession and I cultivate it; he has no right to it. The Holy prophet (may be peace upon him) said to the Hadrami: Have you any proof? We said : No. he (the Prophet)said: Then he will swear an oath for you . He said: Messenger of Allah, he is a reprobate and he would not care to swear to anything and stick at nothing. He said: That is only your recourse}}
\hadithdefcmd{abudawud}{3624}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنَا رَجُلٌ، مِنْ مُزَيْنَةَ - وَنَحْنُ عِنْدَ سَعِيدِ بْنِ الْمُسَيَّبِ - عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم يَعْنِي لِلْيَهُودِ ‏ "‏ أَنْشُدُكُمْ بِاللَّهِ الَّذِي أَنْزَلَ التَّوْرَاةَ عَلَى مُوسَى مَا تَجِدُونَ فِي التَّوْرَاةِ عَلَى مَنْ زَنَى ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ فِي قِصَّةِ الرَّجْمِ ‏.‏\hadithno{3624}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah said:The holy Prophet (ﷺ) said to the Jew : I adjure you by Allah Who sent down the Torah to Moses ! do you not find in the Torah(a rule about a man) who commits adultery. He then narrated the rest of the tradition relating to the stoning}}
\hadithdefcmd{abudawud}{3625}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى أَبُو الأَصْبَغِ، حَدَّثَنِي مُحَمَّدٌ، - يَعْنِي ابْنَ سَلَمَةَ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، بِهَذَا الْحَدِيثِ وَبِإِسْنَادِهِ قَالَ حَدَّثَنِي رَجُلٌ، مِنْ مُزَيْنَةَ مِمَّنْ كَانَ يَتَّبِعُ الْعِلْمَ وَيَعِيهِ يُحَدِّثُ سَعِيدَ بْنَ الْمُسَيَّبِ وَسَاقَ الْحَدِيثَ بِمَعْنَاهُ ‏.‏\hadithno{3625}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by al-Zuhri through a different chain of narrator. This version has:A man from Muzainah who followed the knowledge and memorized it to me that sa’id b.al-Musayyab transmitted it. He then mentioned the rest of the tradition to the same effect}}
\hadithdefcmd{abudawud}{3626}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ يَعْنِي لاِبْنِ صُورِيَا ‏ "‏ أُذَكِّرُكُمْ بِاللَّهِ الَّذِي نَجَّاكُمْ مِنْ آلِ فِرْعَوْنَ وَأَقْطَعَكُمُ الْبَحْرَ وَظَلَّلَ عَلَيْكُمُ الْغَمَامَ وَأَنْزَلَ عَلَيْكُمُ الْمَنَّ وَالسَّلْوَى وَأَنْزَلَ عَلَيْكُمُ التَّوْرَاةَ عَلَى مُوسَى أَتَجِدُونَ فِي كِتَابِكُمُ الرَّجْمَ ‏"‏ ‏.‏ قَالَ ذَكَّرْتَنِي بِعَظِيمٍ وَلاَ يَسَعُنِي أَنْ أَكْذِبَكَ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{3626}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ikrimah: The Holy Prophet (ﷺ) said to Ibn Suriya': I remind you by Allah Who saved you from the people of Pharaoh, made you cover the sea, gave you the shade of clouds, sent down to you manna and quails, sent down you Torah to Moses, do you find stoning (for adultery) in your Book? He said: You have reminded me by the Great. It is not possible for me to belie you. He then transmitted the rest of the tradition}}
\hadithdefcmd{abudawud}{3627}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ، وَمُوسَى بْنُ مَرْوَانَ الرَّقِّيُّ، قَالاَ حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ سَيْفٍ، عَنْ عَوْفِ بْنِ مَالِكٍ، أَنَّهُ حَدَّثَهُمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى بَيْنَ رَجُلَيْنِ ‏.‏ فَقَالَ الْمَقْضِيُّ عَلَيْهِ لَمَّا أَدْبَرَ حَسْبِيَ اللَّهُ وَنِعْمَ الْوَكِيلُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يَلُومُ عَلَى الْعَجْزِ وَلَكِنْ عَلَيْكَ بِالْكَيْسِ فَإِذَا غَلَبَكَ أَمْرٌ فَقُلْ حَسْبِيَ اللَّهُ وَنِعْمَ الْوَكِيلُ ‏"‏ ‏.‏\hadithno{3627}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Awf ibn Malik: The Holy Prophet (ﷺ) gave a decision between two men, and the one against whom the decision was given turned away and said: For me Allah sufficeth, and He is the best dispenser of affairs. The Holy Prophet (ﷺ) said: Allah, Most High, blames for falling short, but apply intelligence, and when the matter gets the better of you, say; For me Allah sufficeth, and He is the best disposer of affairs}}
\hadithdefcmd{abudawud}{3628}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ وَبْرِ بْنِ أَبِي دُلَيْلَةَ، عَنْ مُحَمَّدِ بْنِ مَيْمُونٍ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَىُّ الْوَاجِدِ يُحِلُّ عِرْضَهُ وَعُقُوبَتَهُ ‏"‏ ‏.‏ قَالَ ابْنُ الْمُبَارَكِ يُحِلُّ عِرْضَهُ يُغَلَّظُ لَهُ وَعُقُوبَتَهُ يُحْبَسُ لَهُ ‏.‏\hadithno{3628}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ash-Sharid: The Prophet (ﷺ) said: Delay in payment on the part of one who possesses means makes it lawful to dishonour and punish him. Ibn al-Mubarak said that "dishonour" means that he may be spoken to roughly and "punish" means he may be imprisoned for it}}
\hadithdefcmd{abudawud}{3629}{حَدَّثَنَا مُعَاذُ بْنُ أَسَدٍ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، أَخْبَرَنَا هِرْمَاسُ بْنُ حَبِيبٍ، - رَجُلٌ مِنْ أَهْلِ الْبَادِيَةِ - عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم بِغَرِيمٍ لِي فَقَالَ لِي ‏"‏ الْزَمْهُ ‏"‏ ‏.‏ ثُمَّ قَالَ لِي ‏"‏ يَا أَخَا بَنِي تَمِيمٍ مَا تُرِيدُ أَنْ تَفْعَلَ بِأَسِيرِكَ ‏"‏ ‏.‏\hadithno{3629}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Grandfather of Hirmas ibn Habib: I brought my debtor to the Holy Prophet (ﷺ). He said to me: Stick to him. He again said to me: O brother of Banu Tamim, what do you want to do with your prisoner}}
\hadithdefcmd{abudawud}{3630}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ بَهْزِ بْنِ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم حَبَسَ رَجُلاً فِي تُهْمَةٍ ‏.‏\hadithno{3630}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Bahz bin Hakim, on his father's authority, said that his grandfather told that the Prophet (ﷺ) imprisoned a man on suspicion}}
\hadithdefcmd{abudawud}{3631}{حَدَّثَنَا مُحَمَّدُ بْنُ قُدَامَةَ، وَمُؤَمَّلُ بْنُ هِشَامٍ، - قَالَ ابْنُ قُدَامَةَ - حَدَّثَنِي إِسْمَاعِيلُ، عَنْ بَهْزِ بْنِ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، - قَالَ ابْنُ قُدَامَةَ - إِنَّ أَخَاهُ أَوْ عَمَّهُ وَقَالَ مُؤَمَّلٌ - إِنَّهُ قَامَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يَخْطُبُ فَقَالَ جِيرَانِي بِمَا أَخَذُوا ‏.‏ فَأَعْرَضَ عَنْهُ مَرَّتَيْنِ ثُمَّ ذَكَرَ شَيْئًا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ خَلُّوا لَهُ عَنْ جِيرَانِهِ ‏"‏ ‏.‏ لَمْ يَذْكُرْ مُؤَمَّلٌ وَهُوَ يَخْطُبُ ‏.‏\hadithno{3631}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Bahz ibn Hakim reported from his grandfather:(Ibn Qudamah's version has: His grandfather's brother or uncle reported:) - the narrator Mu'ammal said: - He (his grandfather Mu'awiyah) got up before the Holy Prophet (ﷺ) who was giving sermon: and he said: Why have your companions arrested my neighbours? He turned away from him twice. He (his grandfather Mu'awiyah) then mentioned something. The Holy Prophet (ﷺ) then said: Let his neighbours go. (Mu'ammal did not mention the words "He was giving sermon)}}
\hadithdefcmd{abudawud}{3632}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ، حَدَّثَنَا عَمِّي، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، عَنْ أَبِي نُعَيْمٍ، وَهْبِ بْنِ كَيْسَانَ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَهُ يُحَدِّثُ، قَالَ أَرَدْتُ الْخُرُوجَ إِلَى خَيْبَرَ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَلَّمْتُ عَلَيْهِ وَقُلْتُ لَهُ إِنِّي أَرَدْتُ الْخُرُوجَ إِلَى خَيْبَرَ ‏.‏ فَقَالَ ‏ "‏ إِذَا أَتَيْتَ وَكِيلِي فَخُذْ مِنْهُ خَمْسَةَ عَشَرَ وَسْقًا فَإِنِ ابْتَغَى مِنْكَ آيَةً فَضَعْ يَدَكَ عَلَى تَرْقُوَتِهِ ‏"‏ ‏.‏\hadithno{3632}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: I intended to go (on expedition) to Khaybar. So I came to the Holy Prophet (ﷺ), greeted him and said: I am intending to go to Khaybar. He said: When you come to my agent, you should take from him fifteen wasqs (of dates). If he asks you for a sign, then place your hand on his collar-bone}}
\hadithdefcmd{abudawud}{3633}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْمُثَنَّى بْنُ سَعِيدٍ، حَدَّثَنَا قَتَادَةُ، عَنْ بُشَيْرِ بْنِ كَعْبٍ الْعَدَوِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَدَارَأْتُمْ فِي طَرِيقٍ فَاجْعَلُوهُ سَبْعَةَ أَذْرُعٍ ‏"‏ ‏.‏\hadithno{3633}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If you dispute over a pathway, leave the margin of seven yards}}
\hadithdefcmd{abudawud}{3634}{حَدَّثَنَا مُسَدَّدٌ، وَابْنُ أَبِي خَلَفٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا اسْتَأْذَنَ أَحَدُكُمْ أَخَاهُ أَنْ يَغْرِزَ خَشَبَةً فِي جِدَارِهِ فَلاَ يَمْنَعْهُ ‏"‏ ‏.‏ فَنَكَسُوا فَقَالَ مَا لِي أَرَاكُمْ قَدْ أَعْرَضْتُمْ لأُلْقِيَنَّهَا بَيْنَ أَكْتَافِكُمْ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا حَدِيثُ ابْنِ أَبِي خَلَفٍ وَهُوَ أَتَمُّ ‏.‏\hadithno{3634}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Bukhari (2463) Sahih Muslim (1609)}\hadithtrans{Abu Hurairah reported the Holy Prophet(ﷺ) as saying:When one of you asks permission for inserting a wooden peg in his wall, he should not prevent him. So they (the people) lowered down their heads. Then he (Abu Hurairah) said: What is the matter ? I am seeing you are neglecting (to hear this tradition), I shall spread it among you. Abu Dawud said:This is the tradition of Ibn Abi Khalaf is more perfect}}
\hadithdefcmd{abudawud}{3635}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ لُؤْلُؤَةَ، عَنْ أَبِي صِرْمَةَ، - قَالَ أَبُو دَاوُدَ قَالَ غَيْرُ قُتَيْبَةَ فِي هَذَا الْحَدِيثِ عَنْ أَبِي صِرْمَةَ صَاحِبِ النَّبِيِّ صلى الله عليه وسلم - عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنْ ضَارَّ أَضَرَّ اللَّهُ بِهِ وَمَنْ شَاقَّ شَاقَّ اللَّهُ عَلَيْهِ ‏"‏ ‏.‏\hadithno{3635}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSirmah: The Prophet (ﷺ) said: If anyone harms (others), Allah will harm him, and if anyone shows hostility to others, Allah will show hostility to him}}
\hadithdefcmd{abudawud}{3636}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا وَاصِلٌ، مَوْلَى أَبِي عُيَيْنَةَ قَالَ سَمِعْتُ أَبَا جَعْفَرٍ، مُحَمَّدَ بْنَ عَلِيٍّ يُحَدِّثُ عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، أَنَّهُ كَانَتْ لَهُ عَضُدٌ مِنْ نَخْلٍ فِي حَائِطِ رَجُلٍ مِنَ الأَنْصَارِ قَالَ وَمَعَ الرَّجُلِ أَهْلُهُ قَالَ فَكَانَ سَمُرَةُ يَدْخُلُ إِلَى نَخْلِهِ فَيَتَأَذَّى بِهِ وَيَشُقُّ عَلَيْهِ فَطَلَبَ إِلَيْهِ أَنْ يَبِيعَهُ فَأَبَى فَطَلَبَ إِلَيْهِ أَنْ يُنَاقِلَهُ فَأَبَى فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَطَلَبَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم أَنْ يَبِيعَهُ فَأَبَى فَطَلَبَ إِلَيْهِ أَنْ يُنَاقِلَهُ فَأَبَى ‏.‏ قَالَ ‏"‏ فَهَبْهُ لَهُ وَلَكَ كَذَا وَكَذَا ‏"‏ ‏.‏ أَمْرًا رَغَّبَهُ فِيهِ فَأَبَى فَقَالَ ‏"‏ أَنْتَ مُضَارٌّ ‏"‏ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلأَنْصَارِيِّ ‏"‏ اذْهَبْ فَاقْلَعْ نَخْلَهُ ‏"‏ ‏.‏\hadithno{3636}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Ja'far Muhammad bin 'Ali reported from Samurah ibn Jundub that he had a row of palm-trees in the garden of a man of the Ansar. The man had his family with him. Samurah used to visit his palm-trees, and the man was annoyed by that and felt it keenly. So he asked him (Samurah) to sell them to him, but he refused. He then asked him to take something else in exchange, but he refused. So he came to the Holy Prophet (ﷺ) and mentioned it to him. The Holy Prophet (ﷺ) asked him to sell it to him, but he refused. He asked him to take something else in exchange, but he refused. He then said:Give it to him and you can have such and such, mentioning something with which he tried to please him, but he refused. He then said: You are a nuisance. The Messenger of Allah (ﷺ) then said to the Ansari: Go and uproot his palm-trees}}
\hadithdefcmd{abudawud}{3637}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا اللَّيْثُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، حَدَّثَهُ أَنَّ رَجُلاً خَاصَمَ الزُّبَيْرَ فِي شِرَاجِ الْحَرَّةِ الَّتِي يَسْقُونَ بِهَا فَقَالَ الأَنْصَارِيُّ سَرِّحِ الْمَاءَ يَمُرُّ ‏.‏ فَأَبَى عَلَيْهِ الزُّبَيْرُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلزُّبَيْرِ ‏"‏ اسْقِ يَا زُبَيْرُ ثُمَّ أَرْسِلْ إِلَى جَارِكَ ‏"‏ ‏.‏ فَغَضِبَ الأَنْصَارِيُّ فَقَالَ يَا رَسُولَ اللَّهِ أَنْ كَانَ ابْنَ عَمَّتِكَ فَتَلَوَّنَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ اسْقِ ثُمَّ احْبِسِ الْمَاءَ حَتَّى يَرْجِعَ إِلَى الْجَدْرِ ‏"‏ ‏.‏ فَقَالَ الزُّبَيْرُ فَوَاللَّهِ إِنِّي لأَحْسِبُ هَذِهِ الآيَةَ نَزَلَتْ فِي ذَلِكَ ‏\{‏ فَلاَ وَرَبِّكَ لاَ يُؤْمِنُونَ حَتَّى يُحَكِّمُوكَ ‏\}‏ الآيَةَ ‏.‏\hadithno{3637}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2359، 2360) Sahih Muslim (2357)}\hadithtrans{Narrated Abdullah ibn az-Zubayr: A man disputed with az-Zubayr about streamlets in the lava plain which was irrigated by them. The Ansari said: Release the water and let it run, but az-Zubayr refused. The Holy Prophet (ﷺ) said to az-Zubayr: Water (your ground), Zubayr, then let the water run to your neighbour. The Ansari then became angry and said: Messenger of Allah! it is because he is your cousin! Thereupon the face of the Messenger of Allah (ﷺ) changed colour and he said: Water (your ground), then keep back the water till it returns to the embankment. Az-Zubayr said: By Allah! I think this verse came down about that: "But no , by thy Lord! they can have no (real) faith, until they make thee judge}}
\hadithdefcmd{abudawud}{3638}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ، - يَعْنِي ابْنَ كَثِيرٍ - عَنْ أَبِي مَالِكِ بْنِ ثَعْلَبَةَ، عَنْ أَبِيهِ، ثَعْلَبَةَ بْنِ أَبِي مَالِكٍ أَنَّهُ سَمِعَ كُبَرَاءَهُمْ، يَذْكُرُونَ أَنَّ رَجُلاً، مِنْ قُرَيْشٍ كَانَ لَهُ سَهْمٌ فِي بَنِي قُرَيْظَةَ فَخَاصَمَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِي مَهْزُورٍ - يَعْنِي السَّيْلَ الَّذِي يَقْتَسِمُونَ مَاءَهُ - فَقَضَى بَيْنَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّ الْمَاءَ إِلَى الْكَعْبَيْنِ لاَ يَحْبِسُ الأَعْلَى عَلَى الأَسْفَلِ ‏.‏\hadithno{3638}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Tha'labah ibn AbuMalik: Tha'labah heard his elders say that a man from the Quraysh had his share with Banu Qurayzah (in water). He brought the dispute to the Messenger of Allah (ﷺ) about al-Mahzur, a stream whose water they shared together. The Messenger of Allah (ﷺ) then decided that when water reached the ankles waters should not be held back to flow to the lower}}
\hadithdefcmd{abudawud}{3639}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنِي أَبِي عَبْدُ الرَّحْمَنِ بْنُ الْحَارِثِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِي السَّيْلِ الْمَهْزُورِ أَنْ يُمْسَكَ حَتَّى يَبْلُغَ الْكَعْبَيْنِ ثُمَّ يُرْسِلُ الأَعْلَى عَلَى الأَسْفَلِ ‏.‏\hadithno{3639}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr bin Shu'aib on his father's authority said that his grandfather told that the Messenger of Allah (ﷺ) decided regarding the stream al-Mahzur that its water should be held back till it reached the ankles, and that the upper waters should then be allowed to flow to the lower}}
\hadithdefcmd{abudawud}{3640}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، أَنَّ مُحَمَّدَ بْنَ عُثْمَانَ، حَدَّثَهُمْ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ أَبِي طُوَالَةَ، وَعَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ اخْتَصَمَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم رَجُلاَنِ فِي حَرِيمِ نَخْلَةٍ - فِي حَدِيثِ أَحَدِهِمَا فَأَمَرَ بِهَا فَذُرِعَتْ فَوُجِدَتْ سَبْعَةَ أَذْرُعٍ وَفِي حَدِيثِ الآخَرِ - فَوُجِدَتْ خَمْسَةَ أَذْرُعٍ فَقَضَى بِذَاكَ ‏.‏ قَالَ عَبْدُ الْعَزِيزِ فَأَمَرَ بِجَرِيدَةٍ مِنْ جَرِيدِهَا فَذُرِعَتْ ‏.‏\hadithno{3640}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuSa'id al-Khudri: Two men brought their dispute about the precincts of a palm-tree to the Messenger of Allah (ﷺ). According to a version of this tradition, he ordered to measure and it was measured. It was found seven yards. According to another version, it was found five yards. He made a decision according to that. AbdulAziz said: He ordered to measure with a branch of its branches. It was then measured}}
